@@ -3,6 +3,7 @@
 import threading
 import types
 import random
+import math
 import logging
 import pprint
 import sys
@@ -518,7 +519,7 @@ class SelScraper(threading.Thread):
 
         if self.browser_type != 'browser_type':
             self.webdriver.set_window_size(400, 400)
-            self.webdriver.set_window_position(400*(self.browser_num % 4), 400*(self.browser_num > 4))
+            self.webdriver.set_window_position(400*(self.browser_num % 4), 400*(math.floor(self.browser_num//4)))
 
         for i, kw in enumerate(self.keywords):
             if not kw:
